[gtksourceview] SearchContext: rename forward2() -> forward()



commit ec3f88866bfb503322ceea43a27efe26587aac72
Author: Sébastien Wilmet <swilmet gnome org>
Date:   Tue Nov 15 18:10:11 2016 +0100

    SearchContext: rename forward2() -> forward()
    
    https://bugzilla.gnome.org/show_bug.cgi?id=773249

 docs/reference/gtksourceview-4.0-sections.txt |    2 +-
 gtksourceview/gtksourcesearchcontext.c        |   20 +++++-----
 gtksourceview/gtksourcesearchcontext.h        |    2 +-
 tests/test-search-performances.c              |   14 +++---
 testsuite/test-search-context.c               |   50 ++++++++++++------------
 5 files changed, 44 insertions(+), 44 deletions(-)
---
diff --git a/docs/reference/gtksourceview-4.0-sections.txt b/docs/reference/gtksourceview-4.0-sections.txt
index 84bf010..41c7651 100644
--- a/docs/reference/gtksourceview-4.0-sections.txt
+++ b/docs/reference/gtksourceview-4.0-sections.txt
@@ -682,7 +682,7 @@ gtk_source_search_context_get_match_style
 gtk_source_search_context_set_match_style
 gtk_source_search_context_get_occurrences_count
 gtk_source_search_context_get_occurrence_position
-gtk_source_search_context_forward2
+gtk_source_search_context_forward
 gtk_source_search_context_forward_async
 gtk_source_search_context_forward_finish2
 gtk_source_search_context_backward2
diff --git a/gtksourceview/gtksourcesearchcontext.h b/gtksourceview/gtksourcesearchcontext.h
index 3dac463..b15b377 100644
--- a/gtksourceview/gtksourcesearchcontext.h
+++ b/gtksourceview/gtksourcesearchcontext.h
@@ -94,7 +94,7 @@ gint                   gtk_source_search_context_get_occurrence_position      
(GtkSourceSearchContex
                                                                                 const GtkTextIter       
*match_end);
 
 GTK_SOURCE_AVAILABLE_IN_3_22
-gboolean                gtk_source_search_context_forward2                     (GtkSourceSearchContext 
*search,
+gboolean                gtk_source_search_context_forward                      (GtkSourceSearchContext 
*search,
                                                                                 const GtkTextIter      *iter,
                                                                                 GtkTextIter            
*match_start,
                                                                                 GtkTextIter            
*match_end,
diff --git a/tests/test-search-performances.c b/tests/test-search-performances.c
index 136e0ed..109a28e 100644
--- a/tests/test-search-performances.c
+++ b/tests/test-search-performances.c
@@ -140,7 +140,7 @@ main (int argc, char *argv[])
 
        gtk_text_buffer_get_start_iter (GTK_TEXT_BUFFER (buffer), &iter);
 
-       while (gtk_source_search_context_forward2 (search_context, &iter, NULL, &match_end, NULL))
+       while (gtk_source_search_context_forward (search_context, &iter, NULL, &match_end, NULL))
        {
                iter = match_end;
        }
@@ -159,7 +159,7 @@ main (int argc, char *argv[])
 
        gtk_text_buffer_get_start_iter (GTK_TEXT_BUFFER (buffer), &iter);
 
-       while (gtk_source_search_context_forward2 (search_context, &iter, NULL, &match_end, NULL))
+       while (gtk_source_search_context_forward (search_context, &iter, NULL, &match_end, NULL))
        {
                iter = match_end;
        }
@@ -178,7 +178,7 @@ main (int argc, char *argv[])
 
        gtk_text_buffer_get_start_iter (GTK_TEXT_BUFFER (buffer), &iter);
 
-       while (gtk_source_search_context_forward2 (search_context, &iter, NULL, &match_end, NULL))
+       while (gtk_source_search_context_forward (search_context, &iter, NULL, &match_end, NULL))
        {
                iter = match_end;
        }
@@ -195,7 +195,7 @@ main (int argc, char *argv[])
 
        gtk_text_buffer_get_start_iter (GTK_TEXT_BUFFER (buffer), &iter);
 
-       while (gtk_source_search_context_forward2 (search_context, &iter, NULL, &match_end, NULL))
+       while (gtk_source_search_context_forward (search_context, &iter, NULL, &match_end, NULL))
        {
                iter = match_end;
        }
@@ -212,7 +212,7 @@ main (int argc, char *argv[])
 
        gtk_text_buffer_get_start_iter (GTK_TEXT_BUFFER (buffer), &iter);
 
-       while (gtk_source_search_context_forward2 (search_context, &iter, NULL, &match_end, NULL))
+       while (gtk_source_search_context_forward (search_context, &iter, NULL, &match_end, NULL))
        {
                iter = match_end;
        }
@@ -232,7 +232,7 @@ main (int argc, char *argv[])
 
        gtk_text_buffer_get_start_iter (GTK_TEXT_BUFFER (buffer), &iter);
 
-       while (gtk_source_search_context_forward2 (search_context, &iter, NULL, &match_end, NULL))
+       while (gtk_source_search_context_forward (search_context, &iter, NULL, &match_end, NULL))
        {
                iter = match_end;
        }
@@ -251,7 +251,7 @@ main (int argc, char *argv[])
 
        gtk_text_buffer_get_start_iter (GTK_TEXT_BUFFER (buffer), &iter);
 
-       while (gtk_source_search_context_forward2 (search_context, &iter, NULL, &match_end, NULL))
+       while (gtk_source_search_context_forward (search_context, &iter, NULL, &match_end, NULL))
        {
                iter = match_end;
        }
diff --git a/testsuite/test-search-context.c b/testsuite/test-search-context.c
index 9c8e717..d84fbd1 100644
--- a/testsuite/test-search-context.c
+++ b/testsuite/test-search-context.c
@@ -447,11 +447,11 @@ check_search_results (GtkSourceBuffer        *source_buffer,
 
                if (forward)
                {
-                       found = gtk_source_search_context_forward2 (context,
-                                                                   &iter,
-                                                                   &match_start,
-                                                                   &match_end,
-                                                                   &has_wrapped_around);
+                       found = gtk_source_search_context_forward (context,
+                                                                  &iter,
+                                                                  &match_start,
+                                                                  &match_end,
+                                                                  &has_wrapped_around);
                }
                else
                {
@@ -1051,11 +1051,11 @@ test_regex_at_word_boundaries (void)
 
        gtk_text_buffer_get_start_iter (text_buffer, &iter);
 
-       found = gtk_source_search_context_forward2 (context,
-                                                   &iter,
-                                                   &match_start,
-                                                   &match_end,
-                                                   &has_wrapped_around);
+       found = gtk_source_search_context_forward (context,
+                                                  &iter,
+                                                  &match_start,
+                                                  &match_end,
+                                                  &has_wrapped_around);
        g_assert (found);
        g_assert (!has_wrapped_around);
 
@@ -1065,11 +1065,11 @@ test_regex_at_word_boundaries (void)
        g_assert_cmpint (offset, ==, 4);
 
        iter = match_end;
-       found = gtk_source_search_context_forward2 (context,
-                                                   &iter,
-                                                   &match_start,
-                                                   &match_end,
-                                                   &has_wrapped_around);
+       found = gtk_source_search_context_forward (context,
+                                                  &iter,
+                                                  &match_start,
+                                                  &match_end,
+                                                  &has_wrapped_around);
        g_assert (found);
        g_assert (!has_wrapped_around);
 
@@ -1147,11 +1147,11 @@ test_regex_look_behind (void)
 
        /* Forward search */
        gtk_text_buffer_get_start_iter (text_buffer, &iter);
-       found = gtk_source_search_context_forward2 (context,
-                                                   &iter,
-                                                   &match_start,
-                                                   &match_end,
-                                                   &has_wrapped_around);
+       found = gtk_source_search_context_forward (context,
+                                                  &iter,
+                                                  &match_start,
+                                                  &match_end,
+                                                  &has_wrapped_around);
        g_assert (found);
        g_assert (!has_wrapped_around);
 
@@ -1233,11 +1233,11 @@ test_regex_look_ahead (void)
 
        /* Forward search */
        gtk_text_buffer_get_start_iter (text_buffer, &iter);
-       found = gtk_source_search_context_forward2 (context,
-                                                   &iter,
-                                                   &match_start,
-                                                   &match_end,
-                                                   &has_wrapped_around);
+       found = gtk_source_search_context_forward (context,
+                                                  &iter,
+                                                  &match_start,
+                                                  &match_end,
+                                                  &has_wrapped_around);
        g_assert (found);
        g_assert (!has_wrapped_around);
 


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/gtksourceview/gtksourcesearchcontext.c b/gtksourceview/gtksourcesearchcontext.c
index 05d5b02..941e5dd 100644
--- a/gtksourceview/gtksourcesearchcontext.c
+++ b/gtksourceview/gtksourcesearchcontext.c
@@ -59,7 +59,7 @@
  * For each search, the buffer is scanned at most once. After that, navigating
  * through the occurrences doesn't require to re-scan the buffer entirely.
  *
  * To search forward, use gtk_source_search_context_forward2() or
  * gtk_source_search_context_forward_async() for the asynchronous version.
  * The backward search is done similarly. To replace a search match, or all
  * matches, use gtk_source_search_context_replace2() and
@@ -3181,7 +3181,7 @@ gtk_source_search_context_get_occurrence_position (GtkSourceSearchContext *searc
 }
 
 /**
- * gtk_source_search_context_forward2:
+ * gtk_source_search_context_forward:
  * @search: a #GtkSourceSearchContext.
  * @iter: start of search.
  * @match_start: (out) (optional): return location for start of match, or %NULL.
@@ -3204,11 +3204,11 @@ gtk_source_search_context_get_occurrence_position (GtkSourceSearchContext *searc
  * Since: 3.22
  */
 gboolean
-gtk_source_search_context_forward2 (GtkSourceSearchContext *search,
-                                   const GtkTextIter      *iter,
-                                   GtkTextIter            *match_start,
-                                   GtkTextIter            *match_end,
-                                   gboolean               *has_wrapped_around)
+gtk_source_search_context_forward (GtkSourceSearchContext *search,
+                                  const GtkTextIter      *iter,
+                                  GtkTextIter            *match_start,
+                                  GtkTextIter            *match_end,
+                                  gboolean               *has_wrapped_around)
 {
        GtkTextIter m_start;
        GtkTextIter m_end;
@@ -3263,9 +3263,9 @@ gtk_source_search_context_forward2 (GtkSourceSearchContext *search,
  * @callback: a #GAsyncReadyCallback to call when the operation is finished.
  * @user_data: the data to pass to the @callback function.
  *
  * The asynchronous version of gtk_source_search_context_forward2().
  *
  * See the documentation of gtk_source_search_context_forward2() for more
  * details.
  *
  * See the #GAsyncResult documentation to know how to use this function.
@@ -3310,7 +3310,7 @@ gtk_source_search_context_forward_async (GtkSourceSearchContext *search,
  * Finishes a forward search started with
  * gtk_source_search_context_forward_async().
  *
  * See the documentation of gtk_source_search_context_forward2() for more
  * details.
  *
  * Returns: whether a match was found.
@@ -59,7 +59,7 @@
  * through the occurrences doesn't require to re-scan the buffer entirely.
  *
- * To search forward, use gtk_source_search_context_forward2() or
+ * To search forward, use gtk_source_search_context_forward() or
  * gtk_source_search_context_forward_async() for the asynchronous version.
  * The backward search is done similarly. To replace a search match, or all
@@ -3263,9 +3263,9 @@ gtk_source_search_context_forward2 (GtkSourceSearchContext *search,
  * @user_data: the data to pass to the @callback function.
  *
- * The asynchronous version of gtk_source_search_context_forward2().
+ * The asynchronous version of gtk_source_search_context_forward().
  *
@@ -3263,9 +3263,9 @@ gtk_source_search_context_forward2 (GtkSourceSearchContext *search,
  *
- * See the documentation of gtk_source_search_context_forward2() for more
+ * See the documentation of gtk_source_search_context_forward() for more
  * details.
  *
@@ -3310,7 +3310,7 @@ gtk_source_search_context_forward_async (GtkSourceSearchContext *search,
  * gtk_source_search_context_forward_async().
  *
- * See the documentation of gtk_source_search_context_forward2() for more
+ * See the documentation of gtk_source_search_context_forward() for more
  * details.
  *